==> trosnoth-1.0.1.tar.gz: trosnoth-1.0.1/trosnoth/src/trosnothgui/ingame/colours.py <==
# Trosnoth (UberTweak Platform Game)
# Copyright (C) 2006-2009 Joshua D Bartlett
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# version 2 as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.

'''Team colours.'''
team1bg = (192, 192, 255)
team1msg = (  0,   0, 128)
team1chat = (  0, 185, 238)
team1Mn_zone = (  0, 185, 238)
team1Mn_mk = (192, 192, 255)
team1Mn_pl = (  0,   0, 255)
team1Mn_gh = (  0,   0, 128)

team2bg = (255, 192, 192)
team2msg = (128,   0,   0)
team2chat = (255,  70, 117)
team2Mn_zone = (255,  70, 117)
team2Mn_mk = (255, 192, 192)
team2Mn_pl = (255,   0,   0)
team2Mn_gh = (128,   0,   0)

neutral_bg = (224, 208, 224)

'''Gauge colours.'''
gaugeBorder =       (128, 128, 128)

gaugeRespawnFore =  (255,  69,   0)
gaugeRespawnBack =  (  0, 206, 209)
gaugeRespawnReady = (  0,   0, 255)

gaugeTurretFine =   (  0, 255,   0)
gaugeTurretWarn =   (255, 140,   0)
gaugeTurretHeated = (255,   0,   0)

gaugeUpgradeFore =  (  0, 172,   0)
gaugeUpgradeBack =  (255,   0,   0)

'''Message colours.'''
transactionMessageColour = (192, 192, 0) # For messages pertaining to the            YELLOWY-GOLD
                                         # state of team messages
errorMessageColour = (255,0,0)           # For error messages shown as messages
pregameMessageColour = (192, 128, 64)

'''Menu colours.'''
joinGameBorderColour = (128, 192, 128)
joinGameTitleColour = (0, 0, 0)
joinGameBackgroundColour = (202, 187, 202)

creditsColour = (0, 192, 0)

replayHeadingColour = (0, 192, 0)       # Headings such as "Join game..."            LIGHT, VIBRANT GREEN
joinGameItemColour = (32, 128, 32)      # For menu textElements                      DARK GREEN
inGameButtonColour = (0,128,0)          # For menu buttons                           DARK GREEN
joiningColour = (0, 0, 128)             # For "Joining as %s"                        DARK BLUE
cannotJoinColour = (128, 0, 0)          # For "Unable to join for %f seconds"        DARK RED
joinGameMessage = (192, 0, 192)         # Usually if there is some error in joining  PURPLE
unobtrusivePromptColour = (100,100,0)   # For "%s wants to buy a %s. Contribute?"    GOLD

'''Chat box colours.'''
chatBlueBorder = (0, 0, 255)
chatBlueBackground = (0, 185, 238)

chatRedBorder = (255, 0, 0)
chatRedBackground = (255, 70, 117)

chatAllBorder = (51, 51, 51)
chatAllBackground = (190, 190, 190)

'''Other HUD element colours.'''
minimapBorder = (255, 0, 0)
minimapOwnColour = (0, 255, 0)

zoneBarNeutral = (190, 190, 190)

timerBackground = (51, 51, 51)
timerFontColour = (0, 255, 0)

'''Constants.'''
white = (255, 255, 255)
grey = (128, 128, 128)
black = (0, 0, 0)


#__all__ = ["team1bg", "team1msg", "team1chat", "team1Mn_zone", "team1Mn_mk", \
#           "team1Mn_pl", "team1Mn_gh", "team2bg", "team2msg", "team2chat", \
#           "team2Mn_zone", "team2Mn_mk", "team2Mn_pl", "team2Mn_gh", \
#           "neutral_bg"]

==> trosnoth-1.1.0.tar.gz: trosnoth-1.1.0/trosnoth/src/trosnothgui/ingame/colours.py <==
# Trosnoth (UberTweak Platform Game)
# Copyright (C) 2006-2009 Joshua D Bartlett
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# version 2 as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.

'''Team colours.'''
team1bg = (192, 192, 255)
team1msg = (  0,   0, 128)
team1chat = (  0, 185, 238)
team1Mn_zone = (  0, 185, 238)
team1Mn_mk = (192, 192, 255)
team1Mn_pl = (  0,   0, 255)
team1Mn_gh = (  0,   0, 128)

team2bg = (255, 192, 192)
team2msg = (128,   0,   0)
team2chat = (255,  70, 117)
team2Mn_zone = (255,  70, 117)
team2Mn_mk = (255, 192, 192)
team2Mn_pl = (255,   0,   0)
team2Mn_gh = (128,   0,   0)

neutral_bg = (224, 208, 224)

'''Gauge colours.'''
gaugeBorder =       (128, 128, 128)

gaugeRespawnFore =  (255,  69,   0)
gaugeRespawnBack =  (  0, 206, 209)
gaugeRespawnReady = (  0,   0, 255)

gaugeTurretFine =   (  0, 255,   0)
gaugeTurretWarn =   (255, 140,   0)
gaugeTurretHeated = (255,   0,   0)

gaugeUpgradeFore =  (  0, 172,   0)
gaugeUpgradeBack =  (255,   0,   0)

'''Message colours.'''
transactionMessageColour = (192, 192, 0) # For messages pertaining to the            YELLOWY-GOLD
                                         # state of team messages
errorMessageColour = (255,0,0)           # For error messages shown as messages
pregameMessageColour = (192, 128, 64)

'''Menu colours.'''
joinGameBorderColour = (128, 192, 128)
joinGameTitleColour = (0, 0, 0)
joinGameBackgroundColour = (202, 187, 202)

creditsColour = (0, 192, 0)

replayHeadingColour = (0, 192, 0)       # Headings such as "Join game..."            LIGHT, VIBRANT GREEN
joinGameItemColour = (32, 128, 32)      # For menu textElements                      DARK GREEN
inGameButtonColour = (0,128,0)          # For menu buttons                           DARK GREEN
joiningColour = (0, 0, 128)             # For "Joining as %s"                        DARK BLUE
cannotJoinColour = (128, 0, 0)          # For "Unable to join for %f seconds"        DARK RED
joinGameMessage = (192, 0, 192)         # Usually if there is some error in joining  PURPLE
unobtrusivePromptColour = (100,100,0)   # For "%s wants to buy a %s. Contribute?"    GOLD

'''Chat box colours.'''
chatBlueBorder = (0, 0, 255)
chatBlueBackground = (0, 185, 238)

chatRedBorder = (255, 0, 0)
chatRedBackground = (255, 70, 117)

chatAllBorder = (51, 51, 51)
chatAllBackground = (190, 190, 190)

'''Leaderboard colours.'''
leaderboardNormal = (255, 255, 255)
leaderboardBlue = (0, 185, 238)
leaderboardRed = (255, 70, 117)
leaderboardDead = (153, 153, 153)

'''Other HUD element colours.'''
minimapBorder = (255, 0, 0)
minimapOwnColour = (0, 255, 0)

zoneBarNeutral = (190, 190, 190)

timerBackground = (51, 51, 51)
timerFontColour = (0, 255, 0)
timerFlashColour = (255, 0, 0)

'''Constants.'''
white = (255, 255, 255)
grey = (128, 128, 128)
black = (0, 0, 0)


#__all__ = ["team1bg", "team1msg", "team1chat", "team1Mn_zone", "team1Mn_mk", \
#           "team1Mn_pl", "team1Mn_gh", "team2bg", "team2msg", "team2chat", \
#           "team2Mn_zone", "team2Mn_mk", "team2Mn_pl", "team2Mn_gh", \
#           "neutral_bg"]
